@@ -47,7 +47,7 @@ class Kronolith_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.23)';
+    public $version = 'H5 (4.2.25)';
 
     /**
      * Global variables defined:
@@ -691,9 +691,11 @@ class Kronolith_Application extends Horde_Registry_Application
             if ($user == '-system-' && $share->get('owner')) {
                 continue;
             }
-            $calendar = $calendar_manager
-                ->getEntry(Kronolith::ALL_CALENDARS, $id)
-                ->toHash();
+            if (!$calendar = $calendar_manager->getEntry(Kronolith::ALL_CALENDARS, $id)) {
+                Horde::log(sprintf('Unable to find share id: %s', $id));
+                continue;
+            }
+            $calendar = $calendar->toHash();
             try {
                 $id = $dav->getExternalCollectionId($id, 'calendar');
             } catch (Horde_Dav_Exception $e) {
